@@ -130,66 +130,38 @@ function the_title_rss() {
 }
 
 /**
- * Display the post content for the feed.
- *
- * For encoding the html or the $encode_html parameter, there are three possible
- * values. '0' will make urls footnotes and use make_url_footnote(). '1' will
- * encode special characters and automatically display all of the content. The
- * value of '2' will strip all HTML tags from the content.
- *
- * Also note that you cannot set the amount of words and not set the html
- * encoding. If that is the case, then the html encoding will default to 2,
- * which will strip all HTML tags.
- *
- * To restrict the amount of words of the content, you can use the cut
- * parameter. If the content is less than the amount, then there won't be any
- * dots added to the end. If there is content left over, then dots will be added
- * and the rest of the content will be removed.
+ * Retrieve the post content for feeds.
  *
  * @package WordPress
  * @subpackage Feed
- * @since 0.71
- * @uses apply_filters() Calls 'the_content_rss' on the content before processing.
- * @see get_the_content() For the $more_link_text, $stripteaser, and $more_file
- *		parameters.
+ * @since 2.9.0
+ * @uses apply_filters() Calls 'the_content_feed' on the content before processing.
+ * @see get_the_content()
  *
- * @param string $more_link_text Optional. Text to display when more content is available but not displayed.
- * @param int|bool $stripteaser Optional. Default is 0.
- * @param string $more_file Optional.
- * @param int $cut Optional. Amount of words to keep for the content.
- * @param int $encode_html Optional. How to encode the content.
+ * @param string $feed_type The type of feed. rss2 | atom | rss | rdf
  */
-function the_content_rss($more_link_text='(more...)', $stripteaser=0, $more_file='', $cut = 0, $encode_html = 0) {
-	$content = get_the_content($more_link_text, $stripteaser, $more_file);
-	$content = apply_filters('the_content_rss', $content);
-	if ( $cut && !$encode_html )
-		$encode_html = 2;
-	if ( 1== $encode_html ) {
-		$content = wp_specialchars($content);
-		$cut = 0;
-	} elseif ( 0 == $encode_html ) {
-		$content = make_url_footnote($content);
-	} elseif ( 2 == $encode_html ) {
-		$content = strip_tags($content);
-	}
-	if ( $cut ) {
-		$blah = explode(' ', $content);
-		if ( count($blah) > $cut ) {
-			$k = $cut;
-			$use_dotdotdot = 1;
-		} else {
-			$k = count($blah);
-			$use_dotdotdot = 0;
-		}
+function get_the_content_feed($feed_type = null) {
+	if ( !$feed_type )
+		$feed_type = get_default_feed();
 
-		/** @todo Check performance, might be faster to use array slice instead. */
-		for ( $i=0; $i<$k; $i++ )
-			$excerpt .= $blah[$i].' ';
-		$excerpt .= ($use_dotdotdot) ? '...' : '';
-		$content = $excerpt;
-	}
+	$content = apply_filters('the_content', get_the_content());
 	$content = str_replace(']]>', ']]&gt;', $content);
-	echo $content;
+	return apply_filters('the_content_feed', $content, $feed_type);
+}
+
+/**
+ * Display the post content for feeds.
+ *
+ * @package WordPress
+ * @subpackage Feed
+ * @since 2.9.0
+ * @uses apply_filters() Calls 'the_content_feed' on the content before processing.
+ * @see get_the_content()
+ *
+ * @param string $feed_type The type of feed. rss2 | atom | rss | rdf
+ */
+function the_content_feed($feed_type = null) {
+	echo get_the_content_feed();
 }
 
 /**
@@ -214,7 +186,17 @@ function the_excerpt_rss() {
  * @uses apply_filters() Call 'the_permalink_rss' on the post permalink
  */
 function the_permalink_rss() {
-	echo apply_filters('the_permalink_rss', get_permalink());
+	echo esc_url( apply_filters('the_permalink_rss', get_permalink() ));
+}
+
+/**
+ * Outputs the link to the comments for the current post in an xml safe way
+ *
+ * @since 3.0.0
+ * @return none
+ */
+function comments_link_feed() {
+	echo esc_url( get_comments_link() );
 }
 
 /**
@@ -223,9 +205,11 @@ function the_permalink_rss() {
  * @package WordPress
  * @subpackage Feed
  * @since unknown
+ *
+ * @param int|object $comment_id Optional comment object or id. Defaults to global comment object.
  */
-function comment_guid() {
-	echo get_comment_guid();
+function comment_guid($comment_id = null) {
+	echo esc_url( get_comment_guid($comment_id) );
 }
 
 /**
@@ -235,10 +219,11 @@ function comment_guid() {
  * @subpackage Feed
  * @since unknown
  *
+ * @param int|object $comment_id Optional comment object or id. Defaults to global comment object.
  * @return bool|string false on failure or guid for comment on success.
  */
-function get_comment_guid() {
-	global $comment;
+function get_comment_guid($comment_id = null) {
+	$comment = get_comment($comment_id);
 
 	if ( !is_object($comment) )
 		return false;
@@ -252,7 +237,7 @@ function get_comment_guid() {
  * @since 1.5.0
  */
 function comment_link() {
-	echo get_comment_link();
+	echo esc_url( get_comment_link() );
 }
 
 /**
@@ -306,12 +291,14 @@ function comment_text_rss() {
  * @package WordPress
  * @subpackage Feed
  * @since 2.1.0
- * @uses apply_filters() 
+ * @uses apply_filters()
  *
- * @param string $type Optional, default is 'rss'. Either 'rss', 'atom', or 'rdf'.
+ * @param string $type Optional, default is the type returned by get_default_feed().
  * @return string All of the post categories for displaying in the feed.
  */
-function get_the_category_rss($type = 'rss') {
+function get_the_category_rss($type = null) {
+	if ( empty($type) )
+		$type = get_default_feed();
 	$categories = get_the_category();
 	$tags = get_the_tags();
 	$the_list = '';
@@ -333,11 +320,11 @@ function get_the_category_rss($type = 'rss') {
 
 	foreach ( $cat_names as $cat_name ) {
 		if ( 'rdf' == $type )
-			$the_list .= "\n\t\t<dc:subject><![CDATA[$cat_name]]></dc:subject>\n";
+			$the_list .= "\t\t<dc:subject><![CDATA[$cat_name]]></dc:subject>\n";
 		elseif ( 'atom' == $type )
-			$the_list .= sprintf( '<category scheme="%1$s" term="%2$s" />', attribute_escape( apply_filters( 'get_bloginfo_rss', get_bloginfo( 'url' ) ) ), attribute_escape( $cat_name ) );
+			$the_list .= sprintf( '<category scheme="%1$s" term="%2$s" />', esc_attr( apply_filters( 'get_bloginfo_rss', get_bloginfo( 'url' ) ) ), esc_attr( $cat_name ) );
 		else
-			$the_list .= "\n\t\t<category><![CDATA[$cat_name]]></category>\n";
+			$the_list .= "\t\t<category><![CDATA[" . @html_entity_decode( $cat_name, ENT_COMPAT, get_option('blog_charset') ) . "]]></category>\n";
 	}
 
 	return apply_filters('the_category_rss', $the_list, $type);
@@ -351,9 +338,9 @@ function get_the_category_rss($type = 'rss') {
  * @since 0.71
  * @see get_the_category_rss() For better explanation.
  *
- * @param string $type Optional, default is 'rss'. Either 'rss', 'atom', or 'rdf'.
+ * @param string $type Optional, default is the type returned by get_default_feed().
  */
-function the_category_rss($type = 'rss') {
+function the_category_rss($type = null) {
 	echo get_the_category_rss($type);
 }
 
@@ -394,15 +381,19 @@ function html_type_rss() {
  * @uses get_post_custom() To get the current post enclosure metadata.
  */
 function rss_enclosure() {
-	global $post;
-	if ( !empty($post->post_password) && (!isset($_COOKIE['wp-postpass_'.COOKIEHASH]) || $_COOKIE['wp-postpass_'.COOKIEHASH] != $post->post_password) )
+	if ( post_password_required() )
 		return;
 
-	foreach (get_post_custom() as $key => $val) {
+	foreach ( (array) get_post_custom() as $key => $val) {
 		if ($key == 'enclosure') {
-			foreach ((array)$val as $enc) {
-				$enclosure = split("\n", $enc);
-				echo apply_filters('rss_enclosure', '<enclosure url="' . trim(htmlspecialchars($enclosure[0])) . '" length="' . trim($enclosure[1]) . '" type="' . trim($enclosure[2]) . '" />' . "\n");
+			foreach ( (array) $val as $enc ) {
+				$enclosure = explode("\n", $enc);
+
+				//only get the the first element eg, audio/mpeg from 'audio/mpeg mpga mp2 mp3'
+				$t = preg_split('/[ \t]/', trim($enclosure[2]) );
+				$type = $t[0];
+
+				echo apply_filters('rss_enclosure', '<enclosure url="' . trim(htmlspecialchars($enclosure[0])) . '" length="' . trim($enclosure[1]) . '" type="' . $type . '" />' . "\n");
 			}
 		}
 	}
@@ -426,13 +417,12 @@ function rss_enclosure() {
  * @uses get_post_custom() To get the current post enclosure metadata.
  */
 function atom_enclosure() {
-	global $post;
-	if ( !empty($post->post_password) && ($_COOKIE['wp-postpass_'.COOKIEHASH] != $post->post_password) )
+	if ( post_password_required() )
 		return;
 
-	foreach (get_post_custom() as $key => $val) {
+	foreach ( (array) get_post_custom() as $key => $val ) {
 		if ($key == 'enclosure') {
-			foreach ((array)$val as $enc) {
+			foreach ( (array) $val as $enc ) {
 				$enclosure = split("\n", $enc);
 				echo apply_filters('atom_enclosure', '<link href="' . trim(htmlspecialchars($enclosure[0])) . '" rel="enclosure" length="' . trim($enclosure[1]) . '" type="' . trim($enclosure[2]) . '" />' . "\n");
 			}
@@ -495,9 +485,9 @@ function prep_atom_text_construct($data) {
  * @since 2.5
  */
 function self_link() {
-	$host = @parse_url(get_option('home'));
+	$host = @parse_url(home_url());
 	$host = $host['host'];
-	echo clean_url( 
+	echo esc_url(
 		'http'
 		. ( (isset($_SERVER['https']) && $_SERVER['https'] == 'on') ? 's' : '' ) . '://'
 		. $host
@@ -505,4 +495,52 @@ function self_link() {
 		);
 }
 
-?>
\ No newline at end of file
+/**
+ * Return the content type for specified feed type.
+ *
+ * @package WordPress
+ * @subpackage Feed
+ * @since 2.8.0
+ */
+function feed_content_type( $type = '' ) {
+	if ( empty($type) )
+		$type = get_default_feed();
+
+	$types = array(
+		'rss'  => 'application/rss+xml',
+		'rss2' => 'application/rss+xml',
+		'rss-http'  => 'text/xml',
+		'atom' => 'application/atom+xml',
+		'rdf'  => 'application/rdf+xml'
+	);
+
+	$content_type = ( !empty($types[$type]) ) ? $types[$type] : 'application/octet-stream';
+
+	return apply_filters( 'feed_content_type', $content_type, $type );
+}
+
+/**
+ * Build SimplePie object based on RSS or Atom feed from URL.
+ *
+ * @since 2.8
+ *
+ * @param string $url URL to retrieve feed
+ * @return WP_Error|SimplePie WP_Error object on failure or SimplePie object on success
+ */
+function fetch_feed($url) {
+	require_once (ABSPATH . WPINC . '/class-feed.php');
+
+	$feed = new SimplePie();
+	$feed->set_feed_url($url);
+	$feed->set_cache_class('WP_Feed_Cache');
+	$feed->set_file_class('WP_SimplePie_File');
+	$feed->set_cache_duration(apply_filters('wp_feed_cache_transient_lifetime', 43200, $url));
+	do_action_ref_array( 'wp_feed_options', array( &$feed, $url ) );
+	$feed->init();
+	$feed->handle_content_type();
+
+	if ( $feed->error() )
+		return new WP_Error('simplepie-error', $feed->error());
+
+	return $feed;
+}
